@@ -2,10 +2,12 @@ import inspect
 import logging
 import os.path
 import sys
-import tracemalloc
+import humanfriendly
+import datetime
 
 import boto3
 import click
+import pytz
 from rich.console import Console
 from rich.logging import RichHandler
 
@@ -26,7 +28,9 @@ django.setup()
 
 from preservationdatabase.models import CarinianaPreservation, \
     ClockssPreservation, HathiPreservation, LockssPreservation, \
-    OculScholarsPortalPreservation, PKPPreservation, PorticoPreservation
+    OculScholarsPortalPreservation, PKPPreservation, PorticoPreservation, \
+    LastFill
+
 from django.db import transaction
 import utils
 
@@ -124,6 +128,43 @@ def import_ocul(file, bucket):
     return
 
 
+@click.command()
+@transaction.atomic()
+def stamp_cache_today():
+    """Mark the latest imports as today"""
+    from preservationdatabase.constants import archives
+
+    for key, value in archives.items():
+        LastFill.set_last_fill(value.name())
+
+
+@click.command()
+@transaction.atomic()
+def clear_cache():
+    """Clear the import cache"""
+    LastFill.clear()
+
+
+@click.command()
+@transaction.atomic()
+def show_cache():
+    """Show last fill date/times and cache status"""
+
+    for lf in LastFill.objects.all():
+        logging.info(lf)
+        time_delta = datetime.datetime.now(pytz.utc) - lf.last_fill_date
+        logging.info('Last cache stamp for {} was {}'.format(
+            lf.archive_name,
+            humanfriendly.format_timespan(
+                humanfriendly.coerce_seconds(time_delta))))
+
+        if lf.cache_valid:
+            logging.info('{} will use cached version'.format(lf.archive_name))
+        else:
+            logging.info('{} will be fetched from source'.format(
+                lf.archive_name))
+
+
 @click.command()
 def import_all():
     """Download and import all data (excluding HathiTrust)"""
@@ -172,6 +213,7 @@ def show_preservation(doi):
 
 
 if __name__ == '__main__':
+    cli.add_command(clear_cache)
     cli.add_command(import_all)
     cli.add_command(import_cariniana)
     cli.add_command(import_clockss)
@@ -180,5 +222,7 @@ if __name__ == '__main__':
     cli.add_command(import_ocul)
     cli.add_command(import_pkp)
     cli.add_command(import_portico)
+    cli.add_command(show_cache)
     cli.add_command(show_preservation)
+    cli.add_command(stamp_cache_today)
     cli()
