@@ -3,13 +3,61 @@ import logging
 import re
 import sys
 import tempfile
+import datetime
+from datetime import datetime as dt
 from io import StringIO
 from pathlib import Path
 
+import pytz
 from django.db import models, transaction
 
 from preservationdatabase import utils
 
+LIMIT_TIME_DELTA = datetime.timedelta(weeks=3)
+
+
+class LastFill(models.Model):
+    class Meta:
+        db_table = "preservationData_lastfill"
+        app_label = "preservationdatabase"
+
+    archive_name = models.CharField(max_length=255)
+    last_fill_date = models.DateTimeField(null=True, blank=True)
+
+    @staticmethod
+    def set_last_fill(archive_name, last_fill_date=dt.now(pytz.utc)):
+        lf, created = LastFill.objects.get_or_create(archive_name=archive_name)
+        lf.last_fill_date = last_fill_date
+        lf.save()
+
+    @staticmethod
+    def clear():
+        LastFill.objects.all().delete()
+
+    @staticmethod
+    def get_last_fill(archive_name):
+        try:
+            return \
+                LastFill.objects.get(archive_name=archive_name).last_fill_date
+        except LastFill.DoesNotExist:
+            return None
+
+    def cache_valid(self) -> bool:
+        time_delta = datetime.datetime.now(pytz.utc) - self.last_fill_date
+
+        return True if LIMIT_TIME_DELTA > time_delta else False
+
+    @staticmethod
+    def will_cache(archive_name) -> bool:
+        try:
+            lf = LastFill.objects.get(archive_name=archive_name)
+            return lf.cache_valid()
+        except LastFill.DoesNotExist:
+            return False
+
+    def __str__(self):
+        return '{}: {}'.format(self.archive_name, self.last_fill_date)
+
 
 class Publisher(models.Model):
     class Meta:
